@@ -299,11 +299,13 @@ fn declare_tuple_mutator_helper_types(tb: &mut TokenBuilder, nbr_elements: usize
             "cplx : f64,
             vose_alias : " cm.VoseAlias "
         }
+        #[derive(" cm.Clone ", " cm.Debug ")]
         pub enum InnerMutationStep {"
             join_ts!(0..nbr_elements, i,
                 Ti(i)
             , separator: ",")
         "}
+        #[derive(" cm.Clone ", " cm.Debug ")]
         pub struct MutationStep < " tuple_type_params " > {"
             join_ts!(0..nbr_elements, i,
                 ti(i) ":" Ti(i) ","
@@ -311,6 +313,7 @@ fn declare_tuple_mutator_helper_types(tb: &mut TokenBuilder, nbr_elements: usize
             "inner : " cm.Vec " < InnerMutationStep > ,
             vose_alias : Option<" cm.VoseAlias ">
         }
+        #[derive(" cm.Clone ", " cm.Debug ")]
         pub struct ArbitraryStep < " tuple_type_params " > {"
             join_ts!(0..nbr_elements, i,
                 ti(i) ":" Ti(i)
@@ -437,7 +440,7 @@ fn impl_mutator_trait(tb: &mut TokenBuilder, nbr_elements: usize) {
                 , separator: ",") "
             ];
             let sum_prob = probabilities.iter().sum::<f64>();
-            probabilities.iter_mut().for_each(|c| *c /= sum_prob);
+            probabilities.iter_mut().for_each(#[no_coverage] |c| *c /= sum_prob);
             let vose_alias = " cm.VoseAlias "::new(probabilities);
 
             let step = Self::MutationStep {"
@@ -540,7 +543,7 @@ fn impl_mutator_trait(tb: &mut TokenBuilder, nbr_elements: usize) {
             if sum == 0.0 {
                 step.vose_alias = " cm.None ";
             }  else {
-                prob.iter_mut().for_each(|c| *c /= sum );
+                prob.iter_mut().for_each(#[no_coverage] |c| *c /= sum );
                 step.vose_alias = " cm.Some "(" cm.VoseAlias "::new(prob));
             }
             " SelfAsTupleMutator "::ordered_mutate(self, value, cache, step, max_cplx)
